==> libfwbuilder-3.0.0.tar.gz: libfwbuilder-3.0.0/src/fwbuilder/TCPUDPService.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: TCPUDPService.cpp 177 2008-08-23 23:48:45Z vadim $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/libfwbuilder-config.h>

#include <fwbuilder/TCPUDPService.h>
#include <fwbuilder/XMLTools.h>

using namespace libfwbuilder;
using namespace std;

const char *TCPUDPService::TYPENAME={"TCPUDPService"};

TCPUDPService::TCPUDPService()  
{
    src_range_start = 0;
    src_range_end = 0;
    dst_range_start = 0;
    dst_range_end = 0;
}

TCPUDPService::TCPUDPService(const FWObject *root, bool prepopulate) :
    Service(root,prepopulate) 
{
    src_range_start = 0;
    src_range_end = 0;
    dst_range_start = 0;
    dst_range_end = 0;
}

TCPUDPService::~TCPUDPService() {}

string TCPUDPService::getProtocolName()   {    return ""; }
int    TCPUDPService::getProtocolNumber() {    return -1;    }

void TCPUDPService::fromXML(xmlNodePtr root) throw(FWException)
{
    FWObject::fromXML(root);

    const char *n;

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("src_range_start")));
    if(n!=NULL)
    {
        src_range_start = atol(n);
        FREEXMLBUFF(n);
    }

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("src_range_end")));
    if(n!=NULL)
    {
        src_range_end = atol(n);
        FREEXMLBUFF(n);
    }

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("dst_range_start")));
    if(n!=NULL)
    {
        dst_range_start = atol(n);
        FREEXMLBUFF(n);
    }

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("dst_range_end")));
    if(n!=NULL)
    {
        dst_range_end = atol(n);
        FREEXMLBUFF(n);
    }

}

xmlNodePtr TCPUDPService::toXML(xmlNodePtr xml_parent_node) throw(FWException)
{
    xmlNodePtr me = FWObject::toXML(xml_parent_node);
    xmlNewProp(me, TOXMLCAST("name"), STRTOXMLCAST(getName()));
    xmlNewProp(me, TOXMLCAST("comment"), STRTOXMLCAST(getComment()));

    char str[128];

    sprintf(str,"%d",src_range_start);
    xmlNewProp(me, TOXMLCAST("src_range_start"), TOXMLCAST(str));
    sprintf(str,"%d",src_range_end);
    xmlNewProp(me, TOXMLCAST("src_range_end"), TOXMLCAST(str));

    sprintf(str,"%d",dst_range_start);
    xmlNewProp(me, TOXMLCAST("dst_range_start"), TOXMLCAST(str));
    sprintf(str,"%d",dst_range_end);
    xmlNewProp(me, TOXMLCAST("dst_range_end"), TOXMLCAST(str));
   
    return me;
}

FWObject& TCPUDPService::shallowDuplicate(const FWObject *obj,
                                          bool preserve_id)
    throw(FWException)
{
    const TCPUDPService *other = TCPUDPService::constcast(obj);
    src_range_start = other->src_range_start;
    src_range_end = other->src_range_end;
    dst_range_start = other->dst_range_start;
    dst_range_end = other->dst_range_end;
    return FWObject::shallowDuplicate(obj, preserve_id);
}

==> libfwbuilder-3.0.7.tar.gz: libfwbuilder-3.0.7/src/fwbuilder/TCPUDPService.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: TCPUDPService.cpp 236 2008-12-25 20:36:41Z vadim $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/libfwbuilder-config.h>

#include <fwbuilder/TCPUDPService.h>
#include <fwbuilder/XMLTools.h>

using namespace libfwbuilder;
using namespace std;

const char *TCPUDPService::TYPENAME={"TCPUDPService"};

TCPUDPService::TCPUDPService()  
{
    src_range_start = 0;
    src_range_end = 0;
    dst_range_start = 0;
    dst_range_end = 0;
}

TCPUDPService::TCPUDPService(const FWObjectDatabase *root, bool prepopulate) :
    Service(root,prepopulate) 
{
    src_range_start = 0;
    src_range_end = 0;
    dst_range_start = 0;
    dst_range_end = 0;
}

TCPUDPService::~TCPUDPService() {}

string TCPUDPService::getProtocolName()   {    return ""; }
int    TCPUDPService::getProtocolNumber() {    return -1;    }

void TCPUDPService::fromXML(xmlNodePtr root) throw(FWException)
{
    FWObject::fromXML(root);

    const char *n;

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("src_range_start")));
    if(n!=NULL)
    {
        src_range_start = atol(n);
        FREEXMLBUFF(n);
    }

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("src_range_end")));
    if(n!=NULL)
    {
        src_range_end = atol(n);
        FREEXMLBUFF(n);
    }

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("dst_range_start")));
    if(n!=NULL)
    {
        dst_range_start = atol(n);
        FREEXMLBUFF(n);
    }

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("dst_range_end")));
    if(n!=NULL)
    {
        dst_range_end = atol(n);
        FREEXMLBUFF(n);
    }

}

xmlNodePtr TCPUDPService::toXML(xmlNodePtr xml_parent_node) throw(FWException)
{
    xmlNodePtr me = FWObject::toXML(xml_parent_node);
    xmlNewProp(me, TOXMLCAST("name"), STRTOXMLCAST(getName()));
    xmlNewProp(me, TOXMLCAST("comment"), STRTOXMLCAST(getComment()));
    xmlNewProp(me, TOXMLCAST("ro"), TOXMLCAST(((getRO()) ? "True" : "False")));

    char str[128];

    sprintf(str,"%d",src_range_start);
    xmlNewProp(me, TOXMLCAST("src_range_start"), TOXMLCAST(str));
    sprintf(str,"%d",src_range_end);
    xmlNewProp(me, TOXMLCAST("src_range_end"), TOXMLCAST(str));

    sprintf(str,"%d",dst_range_start);
    xmlNewProp(me, TOXMLCAST("dst_range_start"), TOXMLCAST(str));
    sprintf(str,"%d",dst_range_end);
    xmlNewProp(me, TOXMLCAST("dst_range_end"), TOXMLCAST(str));
   
    return me;
}

FWObject& TCPUDPService::shallowDuplicate(const FWObject *obj,
                                          bool preserve_id)
    throw(FWException)
{
    const TCPUDPService *other = TCPUDPService::constcast(obj);
    src_range_start = other->src_range_start;
    src_range_end = other->src_range_end;
    dst_range_start = other->dst_range_start;
    dst_range_end = other->dst_range_end;
    return FWObject::shallowDuplicate(obj, preserve_id);
}
